# Hunter's Round Counter Addon
#  
# Install instructions:
#       1. Install Mattie's EventScripts 2.0 plugin:
#           http://mattie.info/cs/
#
#       2. Copy and upload this script to:
#           <gamedir>/addons/eventscripts/round_counter/
#
#       3. Add the following line somewhere in autoexec.cfg:
#           es_load round_counter
#
################################################################################
#import EventScripts
import es
#import Libraries
import gamethread
import keyvalues
import langlib
import playerlib
import settinglib
#import Psyco Compiler
import psyco
psyco.full()

# Addon Information
info = es.AddonInfo()
info.name = "Round Counter"
info.version = "4.0.0"
info.author = "Hunter"
info.url = "http://addons.eventscripts.com/addons/user/289"
info.description = "Round Counter that counts the played and remaining rounds"
info.basename = "round_counter"

hunter_round_counter_ver      = info.version
hunter_round_counter_text     = 'Hunters '+info.name+', www.sourceplugins.de, '+info.version+', ES 2.0.0.247+ (Python Version)'

# Server Variables
round_counter_savetime        = es.ServerVar('round_counter_savetime', '30', 'How much days should inactive users be stored, before their settings get deleted? ( default = 30 )')
round_counter_soundload       = es.ServerVar('round_counter_soundload', '1', 'Should the sounds be downloaded with EventScripts?')
round_counter_middle_screen   = es.ServerVar('round_counter_middle_screen', '1', 'Should the round be shown in the middle of the screen? ( 0 = off | 1 = HudHint | 2 = CenterMsg )')
round_counter_default_display = es.ServerVar('round_counter_default_display', '1', 'Default settings for new connecting players')
round_counter_default_text    = es.ServerVar('round_counter_default_text', '1', 'Default settings for new connecting players')
round_counter_default_sound   = es.ServerVar('round_counter_default_sound', '1', 'Default settings for new connecting players')

# Global Variables
round_counter_rounds          = 0
round_counter_roundend        = True
round_counter_mp_maxrounds    = es.ServerVar('mp_maxrounds')
round_counter_language        = langlib.Strings(es.getAddonPath('round_counter')+'/round_counter.ini')

# KeyValues Object
round_counter_kv              = keyvalues.KeyValues(name='round_counter')

# Settinglib Object
round_counter_setting         = settinglib.create('roundcounter', 'Round Counter Settings', 'toggle')

def load():
    public = es.ServerVar('hu_rc', info.version, info.name)
    public.makepublic()

    round_counter_kv.load(es.getAddonPath('round_counter')+'/round_counter.txt')

    round_counter_setting.addoption('display', 'Display')
    round_counter_setting.addoption('text', 'Text')
    round_counter_setting.addoption('sound', 'Sound')
    round_counter_setting.setdefault('display', int(round_counter_default_display))
    round_counter_setting.setdefault('text', int(round_counter_default_text))
    round_counter_setting.setdefault('sound', int(round_counter_default_sound))
    round_counter_setting.addsound('ui/buttonclick.wav')

    es.regsaycmd('!rounds', 'round_counter/saycmd', 'Round Counter Settings')
    es.regsaycmd('!round', 'round_counter/saycmd_info', 'Round Counter Information')
    es.log(hunter_round_counter_text)
    es.msg('#multi', '#green[RoundCounter] #defaultLoaded')
    
def unload():
    es.unregsaycmd('!rounds')
    es.unregsaycmd('!round')
    es.msg('#multi', '#green[RoundCounter] #defaultUnloaded')
    
def es_map_start(event_var):
    global round_counter_rounds, round_counter_roundend
    round_counter_setting.clear(int(round_counter_savetime)*86400)
    round_counter_rounds = 0
    round_counter_roundend = True
    if int(round_counter_soundload):
        for keyname in round_counter_kv:
            if str(keyname)[:6] == 'sounds':
                for soundname in round_counter_kv[str(keyname)]:
                    es.stringtable('downloadables', 'sound/'+str(round_counter_kv[str(keyname)][str(soundname)]))

def es_client_command(event_var):
    if (str(event_var['command']) == '!hunter_round_counter_ver') or (str(event_var['command']) == '!hunter_all_ver'):
        es.cexec(int(event_var['userid']), 'echo '+hunter_round_counter_text)

def player_activate(event_var):
    round_counter_setting.updateTime(int(event_var['userid']))
    gamethread.delayed(30, es.cexec, (int(event_var['userid']), 'echo '+hunter_round_counter_text))
    gamethread.delayed(15, es.tell, (int(event_var['userid']), '#multi', '#green[RoundCounter] #defaultSay \'!rounds\' for settings menu'))

def player_disconnect(event_var):
    round_counter_setting.updateTime(int(event_var['userid']))

def round_start(event_var):
    global round_counter_rounds, round_counter_roundend
    if round_counter_roundend:
        round_counter_rounds = round_counter_rounds + 1
        round_counter_roundend = False
    else:
        round_counter_rounds = 1
    gamethread.delayed(1.5, _run_round, (round_counter_rounds))
    
def round_end(event_var):
    global round_counter_rounds, round_counter_roundend
    round_counter_roundend = True
    if int(event_var['reason']) == 16:
        round_counter_rounds = 0

def saycmd():
    round_counter_setting.send(int(es.getcmduserid()))
    
def saycmd_info():
    global round_counter_rounds
    userid = int(es.getcmduserid())
    if int(round_counter_mp_maxrounds) > 0:
        soundtext = 'Round '+str(round_counter_rounds)+' of '+str(round_counter_mp_maxrounds)
    else:
        soundtext = 'Round '+str(round_counter_rounds)
    if int(round_counter_middle_screen) == 1:
        es.usermsg('create', 'roundcounter', 'HintText')
        es.usermsg('write', 'short', 'roundcounter', '-1')
        es.usermsg('write', 'string', 'roundcounter', str(soundtext))
        es.usermsg('send', 'roundcounter', str(userid))
        es.usermsg('delete', 'roundcounter')
    elif int(round_counter_middle_screen) == 2:
        es.usermsg('create', 'roundcounter', 'TextMsg')
        es.usermsg('write', 'byte', 'roundcounter', '4')
        es.usermsg('write', 'string', 'roundcounter', str(soundtext))
        es.usermsg('send', 'roundcounter', str(userid))
        es.usermsg('delete', 'roundcounter')

def _run_round(ticker):
    if str(ticker) in round_counter_kv['commands'].keys():
        command = str(round_counter_kv['commands'][str(ticker)])
        if (';' in command):
            commandlist = command.split(';')
            for command in commandlist:
                es.ServerCommand(command.strip())
        else:
            es.ServerCommand(command.strip())
    if int(round_counter_mp_maxrounds) > 0:
        soundtext = 'Round '+str(ticker)+' of '+str(round_counter_mp_maxrounds)
    else:
        soundtext = 'Round '+str(ticker)
    if int(round_counter_middle_screen) == 1:
        es.usermsg('create', 'roundcounter', 'HintText')
        es.usermsg('write', 'short', 'roundcounter', '-1')
        es.usermsg('write', 'string', 'roundcounter', str(soundtext))
    elif int(round_counter_middle_screen) == 2:
        es.usermsg('create', 'roundcounter', 'TextMsg')
        es.usermsg('write', 'byte', 'roundcounter', '4')
        es.usermsg('write', 'string', 'roundcounter', str(soundtext))
    useridlist = playerlib.getUseridList('#human')
    for userid in useridlist:
        if round_counter_setting.get('display', userid):
            if int(round_counter_middle_screen) > 0:
                es.usermsg('send', 'roundcounter', str(userid))
        if round_counter_setting.get('text', userid):
            if 'round_'+str(ticker) in round_counter_language.keys():
                player = playerlib.getPlayer(userid)
                soundtext = round_counter_language('round_'+str(ticker), {}, player.get("lang"))
                es.tell(userid, '#multi', soundtext)
        if round_counter_setting.get('sound', userid):
            if int(es.getplayerteam(userid)) < 2:
                keyname = 'sounds_spec'
            elif int(es.getplayerteam(userid)) == 2:
                keyname = 'sounds_t'
            elif int(es.getplayerteam(userid)) == 3:
                keyname = 'sounds_ct'
            if str(ticker) in round_counter_kv[str(keyname)].keys():
                soundfile = str(round_counter_kv[str(keyname)][str(ticker)])
                es.playsound(userid, soundfile, 1.0)
    if int(round_counter_middle_screen) > 0:
        es.usermsg('delete', 'roundcounter')
